==> apache-druid-25.0.0-src.tar.gz: apache-druid-25.0.0-src/web-console/src/views/home-view/home-view.spec.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { shallow } from 'enzyme';
import React from 'react';

import { Capabilities } from '../../utils';

import { HomeView } from './home-view';

describe('HomeView', () => {
  it('matches snapshot (full)', () => {
    const homeView = shallow(<HomeView capabilities={Capabilities.FULL} />);
    expect(homeView).toMatchSnapshot();
  });

  it('matches snapshot (coordinator)', () => {
    const homeView = shallow(<HomeView capabilities={Capabilities.COORDINATOR} />);
    expect(homeView).toMatchSnapshot();
  });

  it('matches snapshot (overlord)', () => {
    const homeView = shallow(<HomeView capabilities={Capabilities.OVERLORD} />);
    expect(homeView).toMatchSnapshot();
  });
});

==> apache-druid-31.0.2-src.tar.gz: apache-druid-31.0.2-src/web-console/src/views/home-view/home-view.spec.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React from 'react';

import { Capabilities } from '../../helpers';
import { shallow } from '../../utils/shallow-renderer';

import { HomeView } from './home-view';

describe('HomeView', () => {
  it('matches snapshot (full)', () => {
    const homeView = shallow(<HomeView capabilities={Capabilities.FULL} />);
    expect(homeView).toMatchSnapshot();
  });

  it('matches snapshot (coordinator)', () => {
    const homeView = shallow(<HomeView capabilities={Capabilities.COORDINATOR} />);
    expect(homeView).toMatchSnapshot();
  });

  it('matches snapshot (overlord)', () => {
    const homeView = shallow(<HomeView capabilities={Capabilities.OVERLORD} />);
    expect(homeView).toMatchSnapshot();
  });
});
